package cn.com.ty.lift.quan.news.controller;

import cn.com.ty.lift.quan.news.dao.entity.QuanNews;
import cn.com.ty.lift.quan.news.dao.entity.model.QuanNewsReq;
import cn.com.ty.lift.quan.news.service.impl.QuanNewsServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 电梯圈新闻公告 前端控制器
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("/news")
public class QuanNewsController {
    private final QuanNewsServiceImpl quanNewsService;

    /**
     * 分页展示置顶新闻+普通新闻
     *
     * @param quanNews [页码, 页大小]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     * @since 2019/12/2 15:39
     */
    @PostMapping("/list")
    public RestResponse list(@RequestBody QuanNewsReq quanNews) {
        return quanNewsService.news(quanNews.getPageNum(), quanNews.getPageSize(), quanNews.getHaveTops());
    }

    /**
     * 置顶/取消置顶
     *
     * @param req [新闻id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     * @since 2019/12/2 15:40
     */
    @PostMapping("/top")
    public RestResponse top(@RequestBody QuanNewsReq req) {
        return quanNewsService.top(req.getId(), req.getType());
    }

    /**
     * 根据id获取新闻
     *
     * @param quanNews [新闻id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     * @since 2019/12/2 15:48
     */
    @PostMapping
    public RestResponse news(@RequestBody QuanNewsReq quanNews) {
        return quanNewsService.getQuanNews(quanNews);
    }


    /**
     * 新增新闻
     *
     * @param req [新闻标题, 新闻内容, 视频文件, 发布人id]
     * @return org.springframework.http.ResponseEntity
     * @since 2019/12/2 15:48
     */
    @PostMapping("/add")
    public RestResponse add(@RequestBody QuanNewsReq req) {
        return quanNewsService.addNew(req);
    }

    /**
     * 根据id更新新闻信息
     *
     * @param quanNews [新闻id, 新闻标题, 新闻内容]
     * @return org.springframework.http.ResponseEntity
     * @since 2019/12/2 15:49
     */
    @PostMapping("/update")
    public RestResponse updateNews(@RequestBody QuanNews quanNews) {
        return quanNewsService.updateNews(quanNews);
    }


    /**
     * 根据id删除新闻
     *
     * @param quanNews [新闻id]
     * @return org.springframework.http.ResponseEntity
     * @since 2019/12/2 15:49
     */
    @PostMapping("/delete")
    public RestResponse delete(@RequestBody QuanNews quanNews) {
        return quanNewsService.delete(quanNews.getId());
    }

    /**
     * 点赞新闻
     *
     * @param req [用户id,新闻id]
     * @return org.springframework.http.ResponseEntity
     */
    @PostMapping("/like")
    public RestResponse like(@RequestBody QuanNewsReq req) {
        return quanNewsService.like(req);
    }

}